# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.conf import settings
from django.utils.html import strip_tags
from django.utils.text import truncate_words

from cms.models.pluginmodel import CMSPlugin
from cms.plugins.text.models import AbstractText

from filer.fields.image import FilerImageField

from jmb.core.db.cmsmodels import StatusModel,WrapModel
###################################
## CMS MODELS                     #
###################################

class CustomTextSettings(AbstractText, StatusModel, WrapModel):
    background_picture = FilerImageField(
        null=True, blank=True,
        default=None,
        verbose_name=_("Background image"),
        help_text=_("(Optional) Use the image as background for text")
    )
    background_url = models.URLField(
        #verify_exists=False,
        null=True, blank=True,
        default=None,
        verbose_name=_("Alternative image url"),
        help_text=_("(Optional) If not empty, use the url form the background image")
    )
    container_attrs = models.CharField(
        _("Container extra attributes"),
        max_length=255,
        blank=True, null=True,
        default=None,
        help_text=_('(Optional) if populated, these attributes (e.g. data-toggle="modal") will be applied to container element (require "Wrap content" checked)')
    )
    extra_classes = models.CharField(
        _("Alt selector"),
        max_length=1200,
        blank=True, null=True,
        default=None,
        help_text=_("(Optional) if populated, background image will be applied to that DOM element instead of container div")
    )
    extra_css = models.TextField(
        verbose_name=_('Extra CSS'),
        null=True, blank=True,
        default=None,
        help_text=_("(Optional) put here extra css rules (directly insert rules, e.g. color: color: #666666;)."
                    "Rules will be applied to Alt selector, otherwise text div container")
    )
    template_name = models.CharField(
        max_length=150,
        choices=settings.CUSTOMTEXT_CMSPLUGIN_TEMPLATES,
        default="custom_text/cms_plugins/custom_text.html",
    )

    def __unicode__(self):
        return '%s%s' % (('On - ' if self.status else 'Off - '),truncate_words(strip_tags(self.body), 3)[:25]+"...")
    class Meta:
        app_label = "custom_text"


