# coding: utf-8

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _
from mptt.models import MPTTModel, TreeForeignKey

from jmb.core.db.models import DateModel, UserModel, StatusModel


class NavItem(MPTTModel, DateModel, UserModel):
    status = models.IntegerField(
        choices=settings.NAVBAR_NAVITEM_STATUS_CODES,
        default=1,
        verbose_name=_('Status'),
        help_text=None, null=True
    )
    is_hightlighted = models.BooleanField(
        verbose_name=_('is hightlighted'),
        default=False,
    )
    is_header = models.BooleanField(
        verbose_name=_('is a dropdown header'),
        default=False,
    )
    label = models.CharField(
        max_length=255,
        verbose_name=_('label'),
    )
    '''
    link = models.URLField(
        verbose_name=_('link'),
        default=settings.NAVITEM_LINK,
        blank=True,
        null=True,
    )
    '''
    link = models.CharField(
        verbose_name=_('url relativo'),
        max_length=255,
        blank=True,
        null=True,
    )
    html_rendered = models.TextField(
        verbose_name=_('html rendered'),
        blank=True,
        null=True,
    )

    parent = TreeForeignKey(
        'self',
        null=True,
        blank=True,
        related_name='children',
        verbose_name=_('parent'),
    )

    class Meta(object):
        verbose_name = _('Nav Item')
        verbose_name_plural = _('Nav Items')

    def __unicode__(self):
        return '%s: %s' % (self.label, self.link)

if settings.CMS_ENABLED:
    import jmb.cms.navbar.cms.plugins